import React, { useState, useRef, useEffect } from 'react';
import { View, ScrollView, Dimensions, StyleSheet, Image } from 'react-native';
const ImageCarousel = ({
  images,
  height,
  width,
  activeDotColor = '#333333',
  inactiveDotColor = '#BCBCBC',
  resizeMode = 'cover',
  carouselTiming = 1000
}) => {
  const [currentPage, setCurrentPage] = useState(0);
  const scrollViewRef = useRef(null);
  const {
    width: screenWidth
  } = Dimensions.get('window');
  useEffect(() => {
    const interval = setInterval(() => {
      if (scrollViewRef.current) {
        const nextPageIndex = (currentPage + 1) % images.length;
        scrollViewRef.current.scrollTo({
          x: nextPageIndex * screenWidth,
          animated: true
        });
      }
    }, carouselTiming);
    return () => clearInterval(interval);
  }, [currentPage, images.length, screenWidth, carouselTiming]);
  const handleScroll = event => {
    const {
      contentOffset
    } = event.nativeEvent;
    const currentPageIndex = Math.round(contentOffset.x / screenWidth);
    setCurrentPage(currentPageIndex);
  };
  const scrollToPage = pageIndex => {
    if (scrollViewRef.current) {
      scrollViewRef.current.scrollTo({
        x: pageIndex * screenWidth,
        animated: true
      });
      setCurrentPage(pageIndex);
    }
  };
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.container, {
      height,
      width
    }]
  }, /*#__PURE__*/React.createElement(ScrollView, {
    ref: scrollViewRef,
    horizontal: true,
    pagingEnabled: true,
    showsHorizontalScrollIndicator: false,
    onScroll: handleScroll,
    scrollEventThrottle: 16
  }, images.map((image, _) => /*#__PURE__*/React.createElement(Image, {
    key: image,
    source: image,
    style: {
      height,
      width
    },
    resizeMode: resizeMode
  }))), /*#__PURE__*/React.createElement(View, {
    style: styles.pagination
  }, images.map((_, index) => /*#__PURE__*/React.createElement(View, {
    key: index,
    style: [styles.paginationDot, {
      backgroundColor: currentPage === index ? activeDotColor : inactiveDotColor
    }],
    onTouchStart: () => scrollToPage(index)
  }))));
};
const styles = StyleSheet.create({
  container: {
    alignItems: 'stretch',
    justifyContent: 'center'
  },
  pagination: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center'
  },
  paginationDot: {
    width: 8,
    height: 8,
    borderRadius: 4,
    marginHorizontal: 5,
    marginTop: 10
  }
});
export default ImageCarousel;
//# sourceMappingURL=index.js.map